---
name: Bug report
about: Create a report to help us improve
labels: bug
---

<!--
Welcome! Before creating a new issue:
* Search for relevant issues
-->

## Description

<!--
Describe the bug clearly and concisely. Include text-based log output (not screenshots) if possible
-->

## Reproduce

<!-- Describe step-by-step instructions to reproduce the behavior -->

1. Make a `pyproject.toml`...
2. Run `doit`...

## Expected behavior

<!--Describe what you expected to happen-->

## Context

<!--Complete the following for context, and add any other relevant context-->

- Operating System and version:
- `doit` version(s):
- `doitoml` version(s):

<!--The more content you provide, the more we can help!-->

<details><summary>Command Line Output</summary>
<pre>
  Paste the output from your command line running `doit list` here
</pre>
</details>
